// ============================================================================
// Rocks'n'Diamonds - McDuffin Strikes Back!
// ----------------------------------------------------------------------------
// (c) 1995-2014 by Artsoft Entertainment
//                  Holger Schemel
//                  info@artsoft.org
//                  https://www.artsoft.org/
// ----------------------------------------------------------------------------
// conf_mus.h
// ============================================================================

// ------- this file was automatically generated -- do not edit by hand -------

#ifndef CONF_MUS_H
#define CONF_MUS_H

// values for music configuration

#define MUS_BACKGROUND					0
#define MUS_BACKGROUND_TITLE_INITIAL			1
#define MUS_BACKGROUND_TITLE				2
#define MUS_BACKGROUND_MAIN				3
#define MUS_BACKGROUND_NAMES				4
#define MUS_BACKGROUND_LEVELS				5
#define MUS_BACKGROUND_LEVELNR				6
#define MUS_BACKGROUND_SCORES				7
#define MUS_BACKGROUND_EDITOR				8
#define MUS_BACKGROUND_INFO				9
#define MUS_BACKGROUND_INFO_ELEMENTS			10
#define MUS_BACKGROUND_INFO_CREDITS			11
#define MUS_BACKGROUND_INFO_PROGRAM			12
#define MUS_BACKGROUND_INFO_VERSION			13
#define MUS_BACKGROUND_INFO_LEVELSET			14
#define MUS_BACKGROUND_SETUP				15
#define MUS_BACKGROUND_TITLESCREEN_INITIAL_1		16
#define MUS_BACKGROUND_TITLESCREEN_INITIAL_2		17
#define MUS_BACKGROUND_TITLESCREEN_INITIAL_3		18
#define MUS_BACKGROUND_TITLESCREEN_INITIAL_4		19
#define MUS_BACKGROUND_TITLESCREEN_INITIAL_5		20
#define MUS_BACKGROUND_TITLESCREEN_1			21
#define MUS_BACKGROUND_TITLESCREEN_2			22
#define MUS_BACKGROUND_TITLESCREEN_3			23
#define MUS_BACKGROUND_TITLESCREEN_4			24
#define MUS_BACKGROUND_TITLESCREEN_5			25
#define MUS_BACKGROUND_TITLEMESSAGE_INITIAL_1		26
#define MUS_BACKGROUND_TITLEMESSAGE_INITIAL_2		27
#define MUS_BACKGROUND_TITLEMESSAGE_INITIAL_3		28
#define MUS_BACKGROUND_TITLEMESSAGE_INITIAL_4		29
#define MUS_BACKGROUND_TITLEMESSAGE_INITIAL_5		30
#define MUS_BACKGROUND_TITLEMESSAGE_1			31
#define MUS_BACKGROUND_TITLEMESSAGE_2			32
#define MUS_BACKGROUND_TITLEMESSAGE_3			33
#define MUS_BACKGROUND_TITLEMESSAGE_4			34
#define MUS_BACKGROUND_TITLEMESSAGE_5			35

#define NUM_MUSIC_FILES					36

#endif	// CONF_MUS_H
